| Title: | Visualizing the Standard Deviation as the Size of a Prism |
|---|---|
| Description: | We visualize the standard deviation of a data set as the size of a prism whose volume equals the total volume of several prisms made from the Empirical Cumulative Distribution Function. |
| Authors: | Hieu Nguyen [aut, cre], Tom Nguyen [aut], Mamunur Rashid [aut], Jyotirmoy Sarkar [aut] |
| Maintainer: | Hieu Nguyen <[email protected]> |
| License: | GPL-3 |
| Version: | 0.1.1 |
| Built: | 2026-06-04 08:08:34 UTC |
| Source: | https://github.com/cran/SDPrism2D |
We visualize the standard deviation of a data set as the size of a prism whose volume equals the total volume of several prisms made from the Empirical Cumulative Distribution Function.
sdprism2d(data, hlim = NULL, xyscale = NULL)sdprism2d(data, hlim = NULL, xyscale = NULL)
data |
The data that a user inputs, usually a vector of values. |
hlim |
Optional, 4 by default. The height limit for the plot of step 2, step3, and step 4. |
xyscale |
Optional, 4 by default. The ratio of scales between the x-axis and the y-axis. |
No return value, the function will open a new window and display the graphs of the 4 steps of visualizing the standard deviation.
sdprism2d(c(10,18,23,30,36),4,4)sdprism2d(c(10,18,23,30,36),4,4)