Welcome to ClientVPS Mirrors

Help for package SDPrism2D
Type: Package
Title: Visualizing the Standard Deviation as the Size of a Prism
Version: 0.1.1
Maintainer: Hieu Nguyen <hieunguyen04062003@gmail.com>
Description: We visualize the standard deviation of a data set as the size of a prism whose volume equals the total volume of several prisms made from the Empirical Cumulative Distribution Function.
License: GPL-3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2022-09-20 12:23:28 UTC; PC
Author: Hieu Nguyen [aut, cre], Tom Nguyen [aut], Mamunur Rashid [aut], Jyotirmoy Sarkar [aut]
Repository: CRAN
Date/Publication: 2022-09-21 08:20:02 UTC

Visualizing the Standard Deviation as the Size of a Prism

Description

We visualize the standard deviation of a data set as the size of a prism whose volume equals the total volume of several prisms made from the Empirical Cumulative Distribution Function.

Usage

sdprism2d(data, hlim = NULL, xyscale = NULL)

Arguments

data

The data that a user inputs, usually a vector of values.

hlim

Optional, 4 by default. The height limit for the plot of step 2, step3, and step 4.

xyscale

Optional, 4 by default. The ratio of scales between the x-axis and the y-axis.

Value

No return value, the function will open a new window and display the graphs of the 4 steps of visualizing the standard deviation.

Examples

  sdprism2d(c(10,18,23,30,36),4,4)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.